@@ -2,11 +2,12 @@ from __future__ import annotations
 
 from .config import setup
 from .convert import DefaultConverter
-from .fields import ForeignKey, Related
+from .fields import FKNested, ForeignKey, Related
 from .schema import ModelSchema
 
 __all__ = (
     "DefaultConverter",
+    "FKNested",
     "ForeignKey",
     "ModelSchema",
     "Related",
